==> cdk-region-info-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/regioninfo/Fact.java <==
package software.amazon.awscdk.regioninfo;

/**
 * A database of regional information.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:37.177Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.regioninfo.$Module.class, fqn = "@aws-cdk/region-info.Fact")
public class Fact extends software.amazon.jsii.JsiiObject {

    protected Fact(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Fact(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Retrieves a fact from this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @return the fact value if it is known, and `undefined` otherwise.
     * @param region the name of the region (e.g: `us-east-1`).
     * @param name the name of the fact being looked up (see the `FactName` class for details).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static java.lang.String find(final java.lang.String region, final java.lang.String name) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "find", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * Registers a new fact in this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @param fact the new fact to be registered.
     * @param allowReplacing whether new facts can replace existing facts or not.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void register(final software.amazon.awscdk.regioninfo.IFact fact, final java.lang.Boolean allowReplacing) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "register", Void.class, new Object[] { java.util.Objects.requireNonNull(fact, "fact is required"), allowReplacing });
    }

    /**
     * Registers a new fact in this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @param fact the new fact to be registered.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void register(final software.amazon.awscdk.regioninfo.IFact fact) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "register", Void.class, new Object[] { java.util.Objects.requireNonNull(fact, "fact is required") });
    }

    /**
     * Removes a fact from the database.
     * 
     * EXPERIMENTAL
     * 
     * @param region the region for which the fact is to be removed.
     * @param name the name of the fact to remove.
     * @param value the value that should be removed (removal will fail if the value is specified, but does not match the current stored value).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void unregister(final java.lang.String region, final java.lang.String name, final java.lang.String value) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "unregister", Void.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required"), value });
    }

    /**
     * Removes a fact from the database.
     * 
     * EXPERIMENTAL
     * 
     * @param region the region for which the fact is to be removed.
     * @param name the name of the fact to remove.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void unregister(final java.lang.String region, final java.lang.String name) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "unregister", Void.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required") });
    }
}

==> cdk-region-info-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/regioninfo/Fact.java <==
package software.amazon.awscdk.regioninfo;

/**
 * A database of regional information.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:26.034Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.regioninfo.$Module.class, fqn = "@aws-cdk/region-info.Fact")
public class Fact extends software.amazon.jsii.JsiiObject {

    protected Fact(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Fact(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Retrieves a fact from this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @return the fact value if it is known, and `undefined` otherwise.
     * @param region the name of the region (e.g: `us-east-1`). This parameter is required.
     * @param name the name of the fact being looked up (see the `FactName` class for details). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static java.lang.String find(final java.lang.String region, final java.lang.String name) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "find", java.lang.String.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * Registers a new fact in this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @param fact the new fact to be registered. This parameter is required.
     * @param allowReplacing whether new facts can replace existing facts or not.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void register(final software.amazon.awscdk.regioninfo.IFact fact, final java.lang.Boolean allowReplacing) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "register", Void.class, new Object[] { java.util.Objects.requireNonNull(fact, "fact is required"), allowReplacing });
    }

    /**
     * Registers a new fact in this Fact database.
     * 
     * EXPERIMENTAL
     * 
     * @param fact the new fact to be registered. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void register(final software.amazon.awscdk.regioninfo.IFact fact) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "register", Void.class, new Object[] { java.util.Objects.requireNonNull(fact, "fact is required") });
    }

    /**
     * Removes a fact from the database.
     * 
     * EXPERIMENTAL
     * 
     * @param region the region for which the fact is to be removed. This parameter is required.
     * @param name the name of the fact to remove. This parameter is required.
     * @param value the value that should be removed (removal will fail if the value is specified, but does not match the current stored value).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void unregister(final java.lang.String region, final java.lang.String name, final java.lang.String value) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "unregister", Void.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required"), value });
    }

    /**
     * Removes a fact from the database.
     * 
     * EXPERIMENTAL
     * 
     * @param region the region for which the fact is to be removed. This parameter is required.
     * @param name the name of the fact to remove. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void unregister(final java.lang.String region, final java.lang.String name) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.regioninfo.Fact.class, "unregister", Void.class, new Object[] { java.util.Objects.requireNonNull(region, "region is required"), java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * EXPERIMENTAL
     * 
     * @return the list of names of AWS regions for which there is at least one registered fact. This
     * may not be an exhaustive list of all available AWS regions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static java.util.List<java.lang.String> getRegions() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.regioninfo.Fact.class, "regions", java.util.List.class));
    }
}
